pub struct Reader<B> { /* private fields */ }Expand description
A Buf adapter which implements io::Read for the inner value.
This struct is generally created by calling reader() on Buf. See
documentation of reader() for more
details.
Implementations
impl<B> Reader<B>where
B: Buf,
impl<B> Reader<B>where
B: Buf,
pub fn get_ref(&self) -> &B
pub fn get_ref(&self) -> &B
Gets a reference to the underlying Buf.
It is inadvisable to directly read from the underlying Buf.
Examples
use bytes::Buf;
let buf = b"hello world".reader();
assert_eq!(b"hello world", buf.get_ref());pub fn get_mut(&mut self) -> &mut B
pub fn get_mut(&mut self) -> &mut B
Gets a mutable reference to the underlying Buf.
It is inadvisable to directly read from the underlying Buf.
pub fn into_inner(self) -> B
pub fn into_inner(self) -> B
Consumes this Reader, returning the underlying value.
Examples
use bytes::Buf;
use std::io;
let mut buf = b"hello world".reader();
let mut dst = vec![];
io::copy(&mut buf, &mut dst).unwrap();
let buf = buf.into_inner();
assert_eq!(0, buf.remaining());Trait Implementations
impl<B> BufRead for Reader<B>where
B: Buf,
impl<B> BufRead for Reader<B>where
B: Buf,
fn fill_buf(&mut self) -> Result<&[u8], Error>
fn fill_buf(&mut self) -> Result<&[u8], Error>
Returns the contents of the internal buffer, filling it with more data from the inner reader if it is empty. Read more
fn consume(&mut self, amt: usize)
fn consume(&mut self, amt: usize)
Tells this buffer that amt bytes have been consumed from the buffer,
so they should no longer be returned in calls to read. Read more
sourcefn has_data_left(&mut self) -> Result<bool, Error>
fn has_data_left(&mut self) -> Result<bool, Error>
buf_read_has_data_left)Check if the underlying Read has any data left to be read. Read more
1.0.0 · sourcefn read_until(
&mut self,
byte: u8,
buf: &mut Vec<u8, Global>
) -> Result<usize, Error>
fn read_until(
&mut self,
byte: u8,
buf: &mut Vec<u8, Global>
) -> Result<usize, Error>
Read all bytes into buf until the delimiter byte or EOF is reached. Read more
1.0.0 · sourcefn read_line(&mut self, buf: &mut String) -> Result<usize, Error>
fn read_line(&mut self, buf: &mut String) -> Result<usize, Error>
Read all bytes until a newline (the 0xA byte) is reached, and append
them to the provided buffer. You do not need to clear the buffer before
appending. Read more
impl<B> Read for Reader<B>where
B: Buf,
impl<B> Read for Reader<B>where
B: Buf,
fn read(&mut self, dst: &mut [u8]) -> Result<usize, Error>
fn read(&mut self, dst: &mut [u8]) -> Result<usize, Error>
Pull some bytes from this source into the specified buffer, returning how many bytes were read. Read more
1.36.0 · sourcefn read_vectored(&mut self, bufs: &mut [IoSliceMut<'_>]) -> Result<usize, Error>
fn read_vectored(&mut self, bufs: &mut [IoSliceMut<'_>]) -> Result<usize, Error>
Like read, except that it reads into a slice of buffers. Read more
sourcefn is_read_vectored(&self) -> bool
fn is_read_vectored(&self) -> bool
can_vector)Determines if this Reader has an efficient read_vectored
implementation. Read more
1.0.0 · sourcefn read_to_end(&mut self, buf: &mut Vec<u8, Global>) -> Result<usize, Error>
fn read_to_end(&mut self, buf: &mut Vec<u8, Global>) -> Result<usize, Error>
Read all bytes until EOF in this source, placing them into buf. Read more
1.0.0 · sourcefn read_to_string(&mut self, buf: &mut String) -> Result<usize, Error>
fn read_to_string(&mut self, buf: &mut String) -> Result<usize, Error>
Read all bytes until EOF in this source, appending them to buf. Read more
1.6.0 · sourcefn read_exact(&mut self, buf: &mut [u8]) -> Result<(), Error>
fn read_exact(&mut self, buf: &mut [u8]) -> Result<(), Error>
Read the exact number of bytes required to fill buf. Read more
sourcefn read_buf(&mut self, buf: BorrowedCursor<'_>) -> Result<(), Error>
fn read_buf(&mut self, buf: BorrowedCursor<'_>) -> Result<(), Error>
read_buf)Pull some bytes from this source into the specified buffer. Read more
sourcefn read_buf_exact(&mut self, cursor: BorrowedCursor<'_>) -> Result<(), Error>
fn read_buf_exact(&mut self, cursor: BorrowedCursor<'_>) -> Result<(), Error>
read_buf)Read the exact number of bytes required to fill cursor. Read more
1.0.0 · sourcefn by_ref(&mut self) -> &mut Self
fn by_ref(&mut self) -> &mut Self
Creates a “by reference” adaptor for this instance of Read. Read more